Class: ModerationAPI::Models::ActionListResponseItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ActionListResponseItem
- Defined in:
- lib/moderation_api/models/action_list_response.rb
Defined Under Namespace
Modules: Position, QueueBehaviour, Type Classes: PossibleValue, Webhook
Instance Attribute Summary collapse
-
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
-
#created_at ⇒ String
The date the action was created.
-
#description ⇒ String?
The description of the action.
-
#filter_in_queue_ids ⇒ Array<String>
The IDs of the queues the action is available in.
-
#free_text ⇒ Boolean
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
-
#id ⇒ String
The ID of the action.
-
#key ⇒ String?
User defined key of the action.
-
#name ⇒ String
The name of the action.
-
#position ⇒ Symbol, ModerationAPI::Models::ActionListResponseItem::Position
Show the action in all queues, selected queues or no queues (to use via API only).
-
#possible_values ⇒ Array<ModerationAPI::Models::ActionListResponseItem::PossibleValue>
The possible values of the action.
-
#queue_behaviour ⇒ Symbol, ModerationAPI::Models::ActionListResponseItem::QueueBehaviour
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
-
#type ⇒ Symbol, ...
The type of the action.
-
#value_required ⇒ Boolean
Whether the action requires a value to be executed.
-
#webhooks ⇒ Array<ModerationAPI::Models::ActionListResponseItem::Webhook>
The action’s webhooks.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, name:, url:, description: nil, moderation_action_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Webhook for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, url:, description: nil, moderation_action_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Webhook for more details.
|
|
# File 'lib/moderation_api/models/action_list_response.rb', line 101
|
Instance Attribute Details
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
16 |
# File 'lib/moderation_api/models/action_list_response.rb', line 16 required :built_in, ModerationAPI::Internal::Type::Boolean, api_name: :builtIn, nil?: true |
#created_at ⇒ String
The date the action was created.
22 |
# File 'lib/moderation_api/models/action_list_response.rb', line 22 required :created_at, String, api_name: :createdAt |
#description ⇒ String?
The description of the action.
87 |
# File 'lib/moderation_api/models/action_list_response.rb', line 87 optional :description, String, nil?: true |
#filter_in_queue_ids ⇒ Array<String>
The IDs of the queues the action is available in.
28 29 30 |
# File 'lib/moderation_api/models/action_list_response.rb', line 28 required :filter_in_queue_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :filterInQueueIds |
#free_text ⇒ Boolean
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
37 |
# File 'lib/moderation_api/models/action_list_response.rb', line 37 required :free_text, ModerationAPI::Internal::Type::Boolean, api_name: :freeText |
#id ⇒ String
The ID of the action.
10 |
# File 'lib/moderation_api/models/action_list_response.rb', line 10 required :id, String |
#key ⇒ String?
User defined key of the action.
93 |
# File 'lib/moderation_api/models/action_list_response.rb', line 93 optional :key, String, nil?: true |
#name ⇒ String
The name of the action.
43 |
# File 'lib/moderation_api/models/action_list_response.rb', line 43 required :name, String |
#position ⇒ Symbol, ModerationAPI::Models::ActionListResponseItem::Position
Show the action in all queues, selected queues or no queues (to use via API only).
50 |
# File 'lib/moderation_api/models/action_list_response.rb', line 50 required :position, enum: -> { ModerationAPI::Models::ActionListResponseItem::Position } |
#possible_values ⇒ Array<ModerationAPI::Models::ActionListResponseItem::PossibleValue>
The possible values of the action. The user will be prompted to select one of these values when executing the action.
57 58 59 |
# File 'lib/moderation_api/models/action_list_response.rb', line 57 required :possible_values, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::Models::ActionListResponseItem::PossibleValue] }, api_name: :possibleValues |
#queue_behaviour ⇒ Symbol, ModerationAPI::Models::ActionListResponseItem::QueueBehaviour
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
66 67 68 |
# File 'lib/moderation_api/models/action_list_response.rb', line 66 required :queue_behaviour, enum: -> { ModerationAPI::Models::ActionListResponseItem::QueueBehaviour }, api_name: :queueBehaviour |
#type ⇒ Symbol, ...
The type of the action.
99 |
# File 'lib/moderation_api/models/action_list_response.rb', line 99 optional :type, enum: -> { ModerationAPI::Models::ActionListResponseItem::Type }, nil?: true |
#value_required ⇒ Boolean
Whether the action requires a value to be executed.
74 |
# File 'lib/moderation_api/models/action_list_response.rb', line 74 required :value_required, ModerationAPI::Internal::Type::Boolean, api_name: :valueRequired |
#webhooks ⇒ Array<ModerationAPI::Models::ActionListResponseItem::Webhook>
The action’s webhooks.
80 81 |
# File 'lib/moderation_api/models/action_list_response.rb', line 80 required :webhooks, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::Models::ActionListResponseItem::Webhook] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/action_list_response.rb', line 144
|