Module: ModerationAPI::Models::ActionListResponseItem::QueueBehaviour
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/moderation_api/models/action_list_response.rb
Overview
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
Constant Summary collapse
- REMOVE =
:REMOVE- ADD =
:ADD- NO_CHANGE =
:NO_CHANGE
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info