Class: ModerationAPI::Models::ActionListResponseItem::Webhook

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/action_list_response.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel

Instance Attribute Details

#descriptionString?

The webhook’s description

Returns:

  • (String, nil)


197
# File 'lib/moderation_api/models/action_list_response.rb', line 197

optional :description, String, nil?: true

#idString

The ID of the webhook.

Returns:

  • (String)


179
# File 'lib/moderation_api/models/action_list_response.rb', line 179

required :id, String

#moderation_action_idString?

The ID of the moderation action to trigger the webhook on. Only used for moderation action webhooks.

Returns:

  • (String, nil)


204
# File 'lib/moderation_api/models/action_list_response.rb', line 204

optional :moderation_action_id, String, api_name: :moderationActionId, nil?: true

#nameString

The webhook’s name, used to identify it in the dashboard

Returns:

  • (String)


185
# File 'lib/moderation_api/models/action_list_response.rb', line 185

required :name, String

#urlString

The webhook’s URL. We’ll call this URL when the event occurs.

Returns:

  • (String)


191
# File 'lib/moderation_api/models/action_list_response.rb', line 191

required :url, String