Class: ModerationAPI::Models::ActionRetrieveResponse::Webhook
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ActionRetrieveResponse::Webhook
- Defined in:
- lib/moderation_api/models/action_retrieve_response.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
The webhook’s description.
-
#id ⇒ String
The ID of the webhook.
-
#moderation_action_id ⇒ String?
The ID of the moderation action to trigger the webhook on.
-
#name ⇒ String
The webhook’s name, used to identify it in the dashboard.
-
#url ⇒ String
The webhook’s URL.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
The webhook’s description
198 |
# File 'lib/moderation_api/models/action_retrieve_response.rb', line 198 optional :description, String, nil?: true |
#id ⇒ String
The ID of the webhook.
180 |
# File 'lib/moderation_api/models/action_retrieve_response.rb', line 180 required :id, String |
#moderation_action_id ⇒ String?
The ID of the moderation action to trigger the webhook on. Only used for moderation action webhooks.
205 |
# File 'lib/moderation_api/models/action_retrieve_response.rb', line 205 optional :moderation_action_id, String, api_name: :moderationActionId, nil?: true |
#name ⇒ String
The webhook’s name, used to identify it in the dashboard
186 |
# File 'lib/moderation_api/models/action_retrieve_response.rb', line 186 required :name, String |
#url ⇒ String
The webhook’s URL. We’ll call this URL when the event occurs.
192 |
# File 'lib/moderation_api/models/action_retrieve_response.rb', line 192 required :url, String |