Class: ModerationAPI::Models::ActionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ActionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moderation_api/models/action_update_params.rb
Overview
Defined Under Namespace
Modules: Position, QueueBehaviour, Type Classes: PossibleValue, Webhook
Instance Attribute Summary collapse
-
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
-
#description ⇒ String?
The description of the action.
-
#filter_in_queue_ids ⇒ Array<String>?
The IDs of the queues the action is available in.
-
#free_text ⇒ Boolean?
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
-
#id ⇒ String
The ID of the action to update.
-
#key ⇒ String?
User defined key of the action.
-
#name ⇒ String?
The name of the action.
-
#position ⇒ Symbol, ...
Show the action in all queues, selected queues or no queues (to use via API only).
-
#possible_values ⇒ Array<ModerationAPI::Models::ActionUpdateParams::PossibleValue>?
The possible values of the action.
-
#queue_behaviour ⇒ Symbol, ...
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
-
#type ⇒ Symbol, ...
The type of the action.
-
#value_required ⇒ Boolean?
Whether the action requires a value to be executed.
-
#webhooks ⇒ Array<ModerationAPI::Models::ActionUpdateParams::Webhook>?
The action’s webhooks.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(value:) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:) ⇒ Object
|
|
# File 'lib/moderation_api/models/action_update_params.rb', line 101
|
Instance Attribute Details
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
20 |
# File 'lib/moderation_api/models/action_update_params.rb', line 20 optional :built_in, ModerationAPI::Internal::Type::Boolean, api_name: :builtIn, nil?: true |
#description ⇒ String?
The description of the action.
26 |
# File 'lib/moderation_api/models/action_update_params.rb', line 26 optional :description, String, nil?: true |
#filter_in_queue_ids ⇒ Array<String>?
The IDs of the queues the action is available in.
32 33 34 |
# File 'lib/moderation_api/models/action_update_params.rb', line 32 optional :filter_in_queue_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :filterInQueueIds |
#free_text ⇒ Boolean?
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
41 |
# File 'lib/moderation_api/models/action_update_params.rb', line 41 optional :free_text, ModerationAPI::Internal::Type::Boolean, api_name: :freeText |
#id ⇒ String
The ID of the action to update.
14 |
# File 'lib/moderation_api/models/action_update_params.rb', line 14 required :id, String |
#key ⇒ String?
User defined key of the action.
47 |
# File 'lib/moderation_api/models/action_update_params.rb', line 47 optional :key, String, nil?: true |
#name ⇒ String?
The name of the action.
53 |
# File 'lib/moderation_api/models/action_update_params.rb', line 53 optional :name, String |
#position ⇒ Symbol, ...
Show the action in all queues, selected queues or no queues (to use via API only).
60 |
# File 'lib/moderation_api/models/action_update_params.rb', line 60 optional :position, enum: -> { ModerationAPI::ActionUpdateParams::Position } |
#possible_values ⇒ Array<ModerationAPI::Models::ActionUpdateParams::PossibleValue>?
The possible values of the action. The user will be prompted to select one of these values when executing the action.
67 68 69 70 71 |
# File 'lib/moderation_api/models/action_update_params.rb', line 67 optional :possible_values, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::ActionUpdateParams::PossibleValue] }, api_name: :possibleValues |
#queue_behaviour ⇒ Symbol, ...
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
78 79 80 |
# File 'lib/moderation_api/models/action_update_params.rb', line 78 optional :queue_behaviour, enum: -> { ModerationAPI::ActionUpdateParams::QueueBehaviour }, api_name: :queueBehaviour |
#type ⇒ Symbol, ...
The type of the action.
86 |
# File 'lib/moderation_api/models/action_update_params.rb', line 86 optional :type, enum: -> { ModerationAPI::ActionUpdateParams::Type }, nil?: true |
#value_required ⇒ Boolean?
Whether the action requires a value to be executed.
92 |
# File 'lib/moderation_api/models/action_update_params.rb', line 92 optional :value_required, ModerationAPI::Internal::Type::Boolean, api_name: :valueRequired |
#webhooks ⇒ Array<ModerationAPI::Models::ActionUpdateParams::Webhook>?
The action’s webhooks.
98 99 |
# File 'lib/moderation_api/models/action_update_params.rb', line 98 optional :webhooks, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::ActionUpdateParams::Webhook] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/action_update_params.rb', line 142
|