Class: ModerationAPI::Models::ActionUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ActionUpdateResponse
- Defined in:
- lib/moderation_api/models/action_update_response.rb
Overview
Defined Under Namespace
Modules: Position, QueueBehaviour, Type Classes: PossibleValue
Instance Attribute Summary collapse
-
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
-
#created_at ⇒ String
The date the action was created.
-
#description ⇒ String?
The description of the action.
-
#filter_in_queue_ids ⇒ Array<String>
The IDs of the queues the action is available in.
-
#free_text ⇒ Boolean
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
-
#id ⇒ String
The ID of the action.
-
#key ⇒ String?
User defined key of the action.
-
#name ⇒ String
The name of the action.
-
#position ⇒ Symbol, ModerationAPI::Models::ActionUpdateResponse::Position
Show the action in all queues, selected queues or no queues (to use via API only).
-
#possible_values ⇒ Array<ModerationAPI::Models::ActionUpdateResponse::PossibleValue>
The possible values of the action.
-
#queue_behaviour ⇒ Symbol, ModerationAPI::Models::ActionUpdateResponse::QueueBehaviour
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
-
#type ⇒ Symbol, ...
The type of the action.
-
#value_required ⇒ Boolean
Whether the action requires a value to be executed.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:) ⇒ Object
|
|
# File 'lib/moderation_api/models/action_update_response.rb', line 95
|
Instance Attribute Details
#built_in ⇒ Boolean?
Whether the action is a built-in action or a custom one.
17 |
# File 'lib/moderation_api/models/action_update_response.rb', line 17 required :built_in, ModerationAPI::Internal::Type::Boolean, api_name: :builtIn, nil?: true |
#created_at ⇒ String
The date the action was created.
23 |
# File 'lib/moderation_api/models/action_update_response.rb', line 23 required :created_at, String, api_name: :createdAt |
#description ⇒ String?
The description of the action.
81 |
# File 'lib/moderation_api/models/action_update_response.rb', line 81 optional :description, String, nil?: true |
#filter_in_queue_ids ⇒ Array<String>
The IDs of the queues the action is available in.
29 30 31 |
# File 'lib/moderation_api/models/action_update_response.rb', line 29 required :filter_in_queue_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :filterInQueueIds |
#free_text ⇒ Boolean
Whether the action allows any text to be entered as a value or if it must be one of the possible values.
38 |
# File 'lib/moderation_api/models/action_update_response.rb', line 38 required :free_text, ModerationAPI::Internal::Type::Boolean, api_name: :freeText |
#id ⇒ String
The ID of the action.
11 |
# File 'lib/moderation_api/models/action_update_response.rb', line 11 required :id, String |
#key ⇒ String?
User defined key of the action.
87 |
# File 'lib/moderation_api/models/action_update_response.rb', line 87 optional :key, String, nil?: true |
#name ⇒ String
The name of the action.
44 |
# File 'lib/moderation_api/models/action_update_response.rb', line 44 required :name, String |
#position ⇒ Symbol, ModerationAPI::Models::ActionUpdateResponse::Position
Show the action in all queues, selected queues or no queues (to use via API only).
51 |
# File 'lib/moderation_api/models/action_update_response.rb', line 51 required :position, enum: -> { ModerationAPI::Models::ActionUpdateResponse::Position } |
#possible_values ⇒ Array<ModerationAPI::Models::ActionUpdateResponse::PossibleValue>
The possible values of the action. The user will be prompted to select one of these values when executing the action.
58 59 60 |
# File 'lib/moderation_api/models/action_update_response.rb', line 58 required :possible_values, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::Models::ActionUpdateResponse::PossibleValue] }, api_name: :possibleValues |
#queue_behaviour ⇒ Symbol, ModerationAPI::Models::ActionUpdateResponse::QueueBehaviour
Whether the action resolves and removes the item, unresolves and re-add it to the queue, or does not change the resolve status.
67 68 69 |
# File 'lib/moderation_api/models/action_update_response.rb', line 67 required :queue_behaviour, enum: -> { ModerationAPI::Models::ActionUpdateResponse::QueueBehaviour }, api_name: :queueBehaviour |
#type ⇒ Symbol, ...
The type of the action.
93 |
# File 'lib/moderation_api/models/action_update_response.rb', line 93 optional :type, enum: -> { ModerationAPI::Models::ActionUpdateResponse::Type }, nil?: true |
#value_required ⇒ Boolean
Whether the action requires a value to be executed.
75 |
# File 'lib/moderation_api/models/action_update_response.rb', line 75 required :value_required, ModerationAPI::Internal::Type::Boolean, api_name: :valueRequired |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/action_update_response.rb', line 136
|