Class: ModerationAPI::Models::Actions::ExecuteExecuteByIDParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moderation_api/models/actions/execute_execute_by_id_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action_id:, author_ids: nil, content_ids: nil, queue_id: nil, value: nil, request_options: {}) ⇒ Object

Parameters:

  • action_id (String)

    The ID or key of the action to execute.

  • author_ids (Array<String>) (defaults to: nil)

    IDs of the authors to apply the action to

  • content_ids (Array<String>) (defaults to: nil)

    The IDs of the content items to perform the action on.

  • queue_id (String) (defaults to: nil)

    The ID of the queue the action was performed from if any.

  • value (String) (defaults to: nil)

    The value of the action. Useful to set a reason for the action etc.

  • request_options (ModerationAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 41

Instance Attribute Details

#action_idString

The ID or key of the action to execute.

Returns:

  • (String)


15
# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 15

required :action_id, String

#author_idsArray<String>?

IDs of the authors to apply the action to

Returns:

  • (Array<String>, nil)


21
# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 21

optional :author_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :authorIds

#content_idsArray<String>?

The IDs of the content items to perform the action on.

Returns:

  • (Array<String>, nil)


27
# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 27

optional :content_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :contentIds

#queue_idString?

The ID of the queue the action was performed from if any.

Returns:

  • (String, nil)


33
# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 33

optional :queue_id, String, api_name: :queueId

#valueString?

The value of the action. Useful to set a reason for the action etc.

Returns:

  • (String, nil)


39
# File 'lib/moderation_api/models/actions/execute_execute_by_id_params.rb', line 39

optional :value, String