Class: ModerationAPI::Models::AuthorCreateResponse::Block
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::AuthorCreateResponse::Block
- Defined in:
- lib/moderation_api/models/author_create_response.rb
Overview
Instance Attribute Summary collapse
-
#reason ⇒ String?
The moderators reason why the author was blocked or suspended.
-
#until_ ⇒ Float?
The timestamp until which they are blocked if the author is suspended.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#reason ⇒ String?
The moderators reason why the author was blocked or suspended.
136 |
# File 'lib/moderation_api/models/author_create_response.rb', line 136 optional :reason, String, nil?: true |
#until_ ⇒ Float?
The timestamp until which they are blocked if the author is suspended.
142 |
# File 'lib/moderation_api/models/author_create_response.rb', line 142 optional :until_, Float, api_name: :until, nil?: true |