Class: ModerationAPI::Models::AuthorUpdateResponse::TrustLevel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/author_update_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(level:, manual:) ⇒ Object

Parameters:

  • level (Float)

    Author trust level (-1, 0, 1, 2, 3, or 4)

  • manual (Boolean)

    True if the trust level was set manually by a moderator



# File 'lib/moderation_api/models/author_update_response.rb', line 265

Instance Attribute Details

#levelFloat

Author trust level (-1, 0, 1, 2, 3, or 4)

Returns:

  • (Float)


257
# File 'lib/moderation_api/models/author_update_response.rb', line 257

required :level, Float

#manualBoolean

True if the trust level was set manually by a moderator

Returns:

  • (Boolean)


263
# File 'lib/moderation_api/models/author_update_response.rb', line 263

required :manual, ModerationAPI::Internal::Type::Boolean