Class: ModerationAPI::Models::ContentSubmitParams::Policy::LowQualityContent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitParams::Policy::LowQualityContent
- Defined in:
- lib/moderation_api/models/content_submit_params.rb
Instance Attribute Summary collapse
- #flag ⇒ Boolean
- #id ⇒ Symbol, :low_quality
-
#min_words ⇒ Integer?
Flag content with fewer than this many words as low-effort.
- #threshold ⇒ Float?
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#flag ⇒ Boolean
851 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 851 required :flag, ModerationAPI::Internal::Type::Boolean |
#id ⇒ Symbol, :low_quality
846 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 846 required :id, const: :low_quality |
#min_words ⇒ Integer?
Flag content with fewer than this many words as low-effort. Defaults to 3. Set to disable by omitting.
858 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 858 optional :min_words, Integer, api_name: :minWords |
#threshold ⇒ Float?
863 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 863 optional :threshold, Float |