Class: ModerationAPI::Models::ContentSubmitResponse::Content
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitResponse::Content
- Defined in:
- lib/moderation_api/models/content_submit_response.rb
Overview
Defined Under Namespace
Modules: Modified
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the content.
-
#masked ⇒ Boolean
Whether any values have been masked.
-
#modified ⇒ String, ...
The modified content, if any.
-
#transcript ⇒ String?
The transcribed text from audio content.
Instance Method Summary collapse
-
#initialize(id:, masked:, modified:, transcript: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Content for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, masked:, modified:, transcript: nil) ⇒ Object
Some parameter documentations has been truncated, see ModerationAPI::Models::ContentSubmitResponse::Content for more details.
Potentially modified content.
|
|
# File 'lib/moderation_api/models/content_submit_response.rb', line 211
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the content. Either the contentId provided by you or an autogenerated ID.
188 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 188 required :id, String |
#masked ⇒ Boolean
Whether any values have been masked.
194 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 194 required :masked, ModerationAPI::Internal::Type::Boolean |
#modified ⇒ String, ...
The modified content, if any.
200 201 202 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 200 required :modified, union: -> { ModerationAPI::Models::ContentSubmitResponse::Content::Modified }, nil?: true |
#transcript ⇒ String?
The transcribed text from audio content. Only present when audio moderation is used and transcript inclusion is enabled on the channel.
209 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 209 optional :transcript, String, nil?: true |