Class: ModerationAPI::Models::ContentSubmitResponse::Evaluation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitResponse::Evaluation
- Defined in:
- lib/moderation_api/models/content_submit_response.rb,
sig/moderation_api/models/content_submit_response.rbs
Overview
Instance Attribute Summary collapse
-
#flag_probability ⇒ Float
The probability that the content should be flagged.
-
#flagged ⇒ Boolean
Whether the content was flagged by any policy.
-
#severity_score ⇒ Float
The severity score of the content.
-
#shadow_flagged ⇒ Boolean?
Whether the content would have been flagged by analyze-only policies (flag: false).
-
#unicode_spoofed ⇒ Boolean?
Whether the content was flagged for Unicode spoofing.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
272 |
# File 'sig/moderation_api/models/content_submit_response.rbs', line 272
def initialize: (
|
Instance Attribute Details
#flag_probability ⇒ Float
The probability that the content should be flagged.
368 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 368 required :flag_probability, Float |
#flagged ⇒ Boolean
Whether the content was flagged by any policy.
374 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 374 required :flagged, ModerationAPI::Internal::Type::Boolean |
#severity_score ⇒ Float
The severity score of the content. A higher score indicates more severe content.
380 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 380 required :severity_score, Float |
#shadow_flagged ⇒ Boolean?
Whether the content would have been flagged by analyze-only policies (flag: false).
387 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 387 optional :shadow_flagged, ModerationAPI::Internal::Type::Boolean |
#unicode_spoofed ⇒ Boolean?
Whether the content was flagged for Unicode spoofing.
393 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 393 optional :unicode_spoofed, ModerationAPI::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
280 |
# File 'sig/moderation_api/models/content_submit_response.rbs', line 280
def to_hash: -> {
|