Class: ModerationAPI::Models::ContentSubmitResponse::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitResponse::Meta
- Defined in:
- lib/moderation_api/models/content_submit_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#channel_key ⇒ String
The unique key of the channel where the content was handled.
- #processing_time ⇒ String?
- #status ⇒ Symbol, ModerationAPI::Models::ContentSubmitResponse::Meta::Status
- #timestamp ⇒ Float
- #usage ⇒ Float
Instance Method Summary collapse
-
#initialize(channel_key:, status:, timestamp:, usage:, processing_time: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Meta for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_key:, status:, timestamp:, usage:, processing_time: nil) ⇒ Object
Some parameter documentations has been truncated, see ModerationAPI::Models::ContentSubmitResponse::Meta for more details.
Metadata about the moderation request
|
|
# File 'lib/moderation_api/models/content_submit_response.rb', line 529
|
Instance Attribute Details
#channel_key ⇒ String
The unique key of the channel where the content was handled. Either the channel provided by you or automatically routed.
507 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 507 required :channel_key, String |
#processing_time ⇒ String?
527 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 527 optional :processing_time, String |
#status ⇒ Symbol, ModerationAPI::Models::ContentSubmitResponse::Meta::Status
512 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 512 required :status, enum: -> { ModerationAPI::Models::ContentSubmitResponse::Meta::Status } |
#timestamp ⇒ Float
517 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 517 required :timestamp, Float |
#usage ⇒ Float
522 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 522 required :usage, Float |