Class: ModerationAPI::Models::ContentSubmitResponse::Recommendation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitResponse::Recommendation
- Defined in:
- lib/moderation_api/models/content_submit_response.rb
Overview
Defined Under Namespace
Modules: Action, ReasonCode
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ModerationAPI::Models::ContentSubmitResponse::Recommendation::Action
The action to take based on the recommendation.
-
#reason_codes ⇒ Array<Symbol, ModerationAPI::Models::ContentSubmitResponse::Recommendation::ReasonCode>
The reason code for the recommendation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action:, reason_codes:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Recommendation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action:, reason_codes:) ⇒ Object
Some parameter documentations has been truncated, see ModerationAPI::Models::ContentSubmitResponse::Recommendation for more details.
The recommendation for the content based on the evaluation.
|
|
# File 'lib/moderation_api/models/content_submit_response.rb', line 852
|
Instance Attribute Details
#action ⇒ Symbol, ModerationAPI::Models::ContentSubmitResponse::Recommendation::Action
The action to take based on the recommendation
842 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 842 required :action, enum: -> { ModerationAPI::Models::ContentSubmitResponse::Recommendation::Action } |
#reason_codes ⇒ Array<Symbol, ModerationAPI::Models::ContentSubmitResponse::Recommendation::ReasonCode>
The reason code for the recommendation. Can be used to display a reason to the user.
849 850 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 849 required :reason_codes, -> { ModerationAPI::Internal::Type::ArrayOf[enum: ModerationAPI::Models::ContentSubmitResponse::Recommendation::ReasonCode] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/content_submit_response.rb', line 872
|