Class: ModerationAPI::Models::QueueGetStatsResponse::Trends::FlaggedContentTrend

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/queue_get_stats_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(label:, trend:) ⇒ Object

Some parameter documentations has been truncated, see ModerationAPI::Models::QueueGetStatsResponse::Trends::FlaggedContentTrend for more details.

Parameters:

  • label (String)

    Content flag/label

  • trend (Float)

    Trend indicator (-1 to 1) showing if this type of flagged content is increasing



# File 'lib/moderation_api/models/queue_get_stats_response.rb', line 239

Instance Attribute Details

#labelString

Content flag/label

Returns:

  • (String)


230
# File 'lib/moderation_api/models/queue_get_stats_response.rb', line 230

required :label, String

#trendFloat

Trend indicator (-1 to 1) showing if this type of flagged content is increasing or decreasing

Returns:

  • (Float)


237
# File 'lib/moderation_api/models/queue_get_stats_response.rb', line 237

required :trend, Float