Class: ModerationAPI::Models::WebhookCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moderation_api/models/webhook_create_params.rb,
sig/moderation_api/models/webhook_create_params.rbs
Overview
Defined Under Namespace
Modules: EventType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModerationAPI
Instance Attribute Summary collapse
-
#description ⇒ String?
The webhook's description.
-
#event_types ⇒ Array<Symbol, ModerationAPI::Models::WebhookCreateParams::EventType>
Event types this webhook subscribes to.
-
#name ⇒ String
The webhook's name, used to identify it in the dashboard.
-
#url ⇒ String
The webhook's URL.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
24 |
# File 'sig/moderation_api/models/webhook_create_params.rbs', line 24
def initialize: (
|
Instance Attribute Details
#description ⇒ String?
The webhook's description
37 |
# File 'lib/moderation_api/models/webhook_create_params.rb', line 37 optional :description, String, nil?: true |
#event_types ⇒ Array<Symbol, ModerationAPI::Models::WebhookCreateParams::EventType>
Event types this webhook subscribes to. One webhook URL receives all events you list here.
15 16 17 18 19 |
# File 'lib/moderation_api/models/webhook_create_params.rb', line 15 required :event_types, -> { ModerationAPI::Internal::Type::ArrayOf[enum: ModerationAPI::WebhookCreateParams::EventType] }, api_name: :eventTypes |
#name ⇒ String
The webhook's name, used to identify it in the dashboard
25 |
# File 'lib/moderation_api/models/webhook_create_params.rb', line 25 required :name, String |
#url ⇒ String
The webhook's URL. We'll call this URL when an event occurs.
31 |
# File 'lib/moderation_api/models/webhook_create_params.rb', line 31 required :url, String |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/moderation_api/models/webhook_create_params.rbs', line 32
def to_hash: -> {
|