Class: ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Author::Block

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/webhook_event.rb,
sig/moderation_api/models/webhook_event.rbs

Overview

See Also:

  • ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Author#block

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeBlock

Returns a new instance of Block.

Parameters:

  • reason: (String, nil)
  • until_: (Float, nil)


2769
# File 'sig/moderation_api/models/webhook_event.rbs', line 2769

def initialize: (?reason: String?, ?until_: Float?) -> void

Instance Attribute Details

#reasonString?

The moderators reason why the author was blocked or suspended.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3639
# File 'lib/moderation_api/models/webhook_event.rb', line 3639

optional :reason, String, nil?: true

#until_Float?

The timestamp until which they are blocked if the author is suspended.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3645
# File 'lib/moderation_api/models/webhook_event.rb', line 3645

optional :until_, Float, api_name: :until, nil?: true

Instance Method Details

#to_hash{ reason: String?, until_: Float? }

Returns:

  • ({ reason: String?, until_: Float? })


2771
# File 'sig/moderation_api/models/webhook_event.rbs', line 2771

def to_hash: -> { reason: String?, until_: Float? }