Class: ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#author ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Author?
The author the action was performed on, if any.
-
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed.
-
#id ⇒ String
Moderation action ID.
-
#item ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item?
The content item the action was performed on, if any.
-
#key ⇒ String?
Customer-defined key identifying this action.
-
#name ⇒ String?
Display name of the action.
-
#queue ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Queue?
The queue the item belongs to, if any.
-
#value ⇒ String?
The value passed to the action when it ran.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(level:, manual:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(level:, manual:) ⇒ Object
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 4360
|
Instance Attribute Details
#author ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Author?
The author the action was performed on, if any
4346 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4346 optional :author, -> { ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Author } |
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed
4322 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4322 required :created_at, Time |
#id ⇒ String
Moderation action ID
4316 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4316 required :id, String |
#item ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item?
The content item the action was performed on, if any
4352 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4352 optional :item, -> { ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Item } |
#key ⇒ String?
Customer-defined key identifying this action
4328 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4328 required :key, String, nil?: true |
#name ⇒ String?
Display name of the action
4334 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4334 required :name, String, nil?: true |
#queue ⇒ ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Queue?
The queue the item belongs to, if any
4358 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4358 optional :queue, -> { ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Queue } |
#value ⇒ String?
The value passed to the action when it ran
4340 |
# File 'lib/moderation_api/models/webhook_event.rb', line 4340 required :value, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 5223
|