Class: ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item::Label
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item::Label
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Defined Under Namespace
Classes: Match
Instance Attribute Summary collapse
-
#flagged ⇒ Boolean?
Whether this label crossed its flagging threshold.
-
#label ⇒ String
The label name.
-
#manual ⇒ Boolean?
True if the label was applied manually by a moderator.
- #matches ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item::Label::Match>?
-
#score ⇒ Float
Confidence score between 0 and 1.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#flagged ⇒ Boolean?
Whether this label crossed its flagging threshold
5044 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5044 optional :flagged, ModerationAPI::Internal::Type::Boolean |
#label ⇒ String
The label name
5032 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5032 required :label, String |
#manual ⇒ Boolean?
True if the label was applied manually by a moderator
5050 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5050 optional :manual, ModerationAPI::Internal::Type::Boolean |
#matches ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item::Label::Match>?
5055 5056 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5055 optional :matches, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Item::Label::Match] } |
#score ⇒ Float
Confidence score between 0 and 1
5038 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5038 required :score, Float |