Class: ModerationAPI::Models::ActionUpdateParams::Webhook
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ActionUpdateParams::Webhook
- Defined in:
- lib/moderation_api/models/action_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
The webhook’s description.
-
#id ⇒ String?
ID of an existing webhook or undefined if this is a new webhook.
-
#name ⇒ String
The webhook’s name, used to identify it in the dashboard.
-
#url ⇒ String
The webhook’s URL.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, url:, id: nil, description: nil) ⇒ Object
|
|
# File 'lib/moderation_api/models/action_update_params.rb', line 214
|
Instance Attribute Details
#description ⇒ String?
The webhook’s description
212 |
# File 'lib/moderation_api/models/action_update_params.rb', line 212 optional :description, String, nil?: true |
#id ⇒ String?
ID of an existing webhook or undefined if this is a new webhook.
206 |
# File 'lib/moderation_api/models/action_update_params.rb', line 206 optional :id, String |
#name ⇒ String
The webhook’s name, used to identify it in the dashboard
194 |
# File 'lib/moderation_api/models/action_update_params.rb', line 194 required :name, String |
#url ⇒ String
The webhook’s URL. We’ll call this URL when the event occurs.
200 |
# File 'lib/moderation_api/models/action_update_params.rb', line 200 required :url, String |