Class: ModerationAPI::Models::Actions::ExecuteExecuteParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::Actions::ExecuteExecuteParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moderation_api/models/actions/execute_execute_params.rb
Overview
Instance Attribute Summary collapse
-
#action_key ⇒ String
ID or key of the action to execute.
-
#author_ids ⇒ Array<String>?
IDs of the authors to apply the action to.
-
#content_ids ⇒ Array<String>?
IDs of the content items to apply the action to.
-
#duration ⇒ Float?
Optional duration in milliseconds for actions with timeouts.
-
#queue_id ⇒ String?
Optional queue ID if the action is queue-specific.
-
#value ⇒ String?
Optional value to provide with the action.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_key:, author_ids: nil, content_ids: nil, duration: nil, queue_id: nil, value: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 47
|
Instance Attribute Details
#action_key ⇒ String
ID or key of the action to execute
15 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 15 required :action_key, String, api_name: :actionKey |
#author_ids ⇒ Array<String>?
IDs of the authors to apply the action to. Provide this or contentIds.
21 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 21 optional :author_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :authorIds |
#content_ids ⇒ Array<String>?
IDs of the content items to apply the action to. Provide this or authorIds.
27 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 27 optional :content_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :contentIds |
#duration ⇒ Float?
Optional duration in milliseconds for actions with timeouts
33 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 33 optional :duration, Float |
#queue_id ⇒ String?
Optional queue ID if the action is queue-specific
39 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 39 optional :queue_id, String, api_name: :queueId |
#value ⇒ String?
Optional value to provide with the action
45 |
# File 'lib/moderation_api/models/actions/execute_execute_params.rb', line 45 optional :value, String |