Class: ModerationAPI::Models::ContentSubmitParams::Policy::URLRisk
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitParams::Policy::URLRisk
- Defined in:
- lib/moderation_api/models/content_submit_params.rb
Instance Attribute Summary collapse
-
#allowlist_wordlist_ids ⇒ Array<String>?
IDs of wordlists whose entries are treated as allowed URL domains.
-
#blocklist_wordlist_ids ⇒ Array<String>?
IDs of wordlists whose entries are treated as blocked URL domains.
- #flag ⇒ Boolean
- #id ⇒ Symbol, :url_risk
- #threshold ⇒ Float?
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#allowlist_wordlist_ids ⇒ Array<String>?
IDs of wordlists whose entries are treated as allowed URL domains. Matches short-circuit the risk model and are never flagged.
1034 1035 1036 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 1034 optional :allowlist_wordlist_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :allowlistWordlistIds |
#blocklist_wordlist_ids ⇒ Array<String>?
IDs of wordlists whose entries are treated as blocked URL domains. Matches short-circuit the risk model and are always flagged. Blocklists take precedence over allowlists.
1044 1045 1046 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 1044 optional :blocklist_wordlist_ids, ModerationAPI::Internal::Type::ArrayOf[String], api_name: :blocklistWordlistIds |
#flag ⇒ Boolean
1027 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 1027 required :flag, ModerationAPI::Internal::Type::Boolean |
#id ⇒ Symbol, :url_risk
1022 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 1022 required :id, const: :url_risk |
#threshold ⇒ Float?
1051 |
# File 'lib/moderation_api/models/content_submit_params.rb', line 1051 optional :threshold, Float |