Class: ModerationAPI::Models::ContentSubmitResponse::Policy::ClassifierOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::ContentSubmitResponse::Policy::ClassifierOutput
- Defined in:
- lib/moderation_api/models/content_submit_response.rb
Defined Under Namespace
Classes: Label
Instance Attribute Summary collapse
- #flagged ⇒ Boolean
-
#flagged_fields ⇒ Array<String>?
The keys of the flagged fields if submitting an object.
-
#id ⇒ String
The unique identifier for the classifier output.
- #labels ⇒ Array<ModerationAPI::Models::ContentSubmitResponse::Policy::ClassifierOutput::Label>?
- #probability ⇒ Float
- #type ⇒ Symbol, :classifier
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModerationAPI::Internal::Type::BaseModel
Instance Attribute Details
#flagged ⇒ Boolean
577 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 577 required :flagged, ModerationAPI::Internal::Type::Boolean |
#flagged_fields ⇒ Array<String>?
The keys of the flagged fields if submitting an object.
593 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 593 optional :flagged_fields, ModerationAPI::Internal::Type::ArrayOf[String] |
#id ⇒ String
The unique identifier for the classifier output.
572 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 572 required :id, String |
#labels ⇒ Array<ModerationAPI::Models::ContentSubmitResponse::Policy::ClassifierOutput::Label>?
598 599 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 598 optional :labels, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::Models::ContentSubmitResponse::Policy::ClassifierOutput::Label] } |
#probability ⇒ Float
582 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 582 required :probability, Float |
#type ⇒ Symbol, :classifier
587 |
# File 'lib/moderation_api/models/content_submit_response.rb', line 587 required :type, const: :classifier |