Class: ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#author ⇒ ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object::Author
The author the action was performed on.
-
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed.
-
#id ⇒ String
Moderation action ID.
-
#key ⇒ String?
Customer-defined key identifying this action.
-
#name ⇒ String?
Display name of the action.
-
#queue ⇒ ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object::Queue?
The queue the item belongs to, if any.
-
#value ⇒ String?
The value passed to the action when it ran.
Instance Method Summary collapse
- #initialize(level:, manual:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(level:, manual:) ⇒ Object
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 2029
|
Instance Attribute Details
#author ⇒ ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object::Author
The author the action was performed on
1997 |
# File 'lib/moderation_api/models/webhook_event.rb', line 1997 required :author, -> { ModerationAPI::WebhookEvent::AuthorAction::Data::Object::Author } |
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed
2003 |
# File 'lib/moderation_api/models/webhook_event.rb', line 2003 required :created_at, Time |
#id ⇒ String
Moderation action ID
1991 |
# File 'lib/moderation_api/models/webhook_event.rb', line 1991 required :id, String |
#key ⇒ String?
Customer-defined key identifying this action
2009 |
# File 'lib/moderation_api/models/webhook_event.rb', line 2009 required :key, String, nil?: true |
#name ⇒ String?
Display name of the action
2015 |
# File 'lib/moderation_api/models/webhook_event.rb', line 2015 required :name, String, nil?: true |
#queue ⇒ ModerationAPI::Models::WebhookEvent::AuthorAction::Data::Object::Queue?
The queue the item belongs to, if any
2027 |
# File 'lib/moderation_api/models/webhook_event.rb', line 2027 optional :queue, -> { ModerationAPI::WebhookEvent::AuthorAction::Data::Object::Queue } |
#value ⇒ String?
The value passed to the action when it ran
2021 |
# File 'lib/moderation_api/models/webhook_event.rb', line 2021 required :value, String, nil?: true |