Class: ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#author ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Author?
The author the action was performed on, if any.
-
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed.
-
#id ⇒ String
Moderation action ID.
-
#item ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item?
The content item the action was performed on, if any.
-
#key ⇒ String?
Customer-defined key identifying this action.
-
#name ⇒ String?
Display name of the action.
-
#queue ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Queue?
The queue the item belongs to, if any.
-
#value ⇒ String?
The value passed to the action when it ran.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(level:, manual:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(level:, manual:) ⇒ Object
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 3378
|
Instance Attribute Details
#author ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Author?
The author the action was performed on, if any
3364 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3364 optional :author, -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Author } |
#created_at ⇒ Time
ISO 8601 timestamp of when the action was performed
3340 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3340 required :created_at, Time |
#id ⇒ String
Moderation action ID
3334 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3334 required :id, String |
#item ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item?
The content item the action was performed on, if any
3370 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3370 optional :item, -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Item } |
#key ⇒ String?
Customer-defined key identifying this action
3346 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3346 required :key, String, nil?: true |
#name ⇒ String?
Display name of the action
3352 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3352 required :name, String, nil?: true |
#queue ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Queue?
The queue the item belongs to, if any
3376 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3376 optional :queue, -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Queue } |
#value ⇒ String?
The value passed to the action when it ran
3358 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3358 required :value, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 4239
|