Class: ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Overview
Defined Under Namespace
Modules: Content, MetaType Classes: ClientAction, Label
Instance Attribute Summary collapse
-
#author_id ⇒ String?
External author ID (the customer’s identifier, not Moderation API’s internal id).
-
#channel_key ⇒ String?
The channel the content was submitted to, identified by your customer-defined channel key.
-
#client_action ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::ClientAction?
A recommendation from your own client-side flagging.
-
#content ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Text, ...
The original content payload.
-
#conversation_id ⇒ String?
Conversation grouping ID, if any.
-
#flagged ⇒ Boolean?
Whether the content was flagged by moderation.
-
#id ⇒ String
Content ID from your system.
-
#labels ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Label>?
Moderation labels applied to the content.
-
#language ⇒ String?
Detected ISO language code, if available.
-
#meta_type ⇒ Symbol, ...
High-level content type (e.g. message, post, comment).
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata.
-
#timestamp ⇒ Time
ISO 8601 timestamp of when the content was submitted.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Text, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Image, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Video, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Audio, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Object)
Instance Method Summary collapse
- #initialize(brand:, method_:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand:, method_:) ⇒ Object
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 3855
|
Instance Attribute Details
#author_id ⇒ String?
External author ID (the customer’s identifier, not Moderation API’s internal id)
3778 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3778 required :author_id, String, nil?: true |
#channel_key ⇒ String?
The channel the content was submitted to, identified by your customer-defined channel key.
3785 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3785 required :channel_key, String, nil?: true |
#client_action ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::ClientAction?
A recommendation from your own client-side flagging.
3791 3792 3793 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3791 required :client_action, -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Item::ClientAction }, nil?: true |
#content ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Text, ...
The original content payload
3799 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3799 required :content, union: -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Item::Content } |
#conversation_id ⇒ String?
Conversation grouping ID, if any
3805 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3805 required :conversation_id, String, nil?: true |
#flagged ⇒ Boolean?
Whether the content was flagged by moderation
3811 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3811 required :flagged, ModerationAPI::Internal::Type::Boolean, nil?: true |
#id ⇒ String
Content ID from your system
3772 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3772 required :id, String |
#labels ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Label>?
Moderation labels applied to the content
3817 3818 3819 3820 3821 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3817 required :labels, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Item::Label] }, nil?: true |
#language ⇒ String?
Detected ISO language code, if available
3827 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3827 required :language, String, nil?: true |
#meta_type ⇒ Symbol, ...
High-level content type (e.g. message, post, comment). Defaults to the channel’s configured content type but can be overridden per request via the moderation API ‘type` field.
3835 3836 3837 3838 3839 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3835 required :meta_type, enum: -> { ModerationAPI::WebhookEvent::QueueItemAction::Data::Object::Item::MetaType }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata. Top-level keys are strings.
3845 3846 3847 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3845 required :metadata, ModerationAPI::Internal::Type::HashOf[ModerationAPI::Internal::Type::Unknown], nil?: true |
#timestamp ⇒ Time
ISO 8601 timestamp of when the content was submitted
3853 |
# File 'lib/moderation_api/models/webhook_event.rb', line 3853 required :timestamp, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 3954
|
.variants ⇒ Array(ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Text, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Image, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Video, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Audio, ModerationAPI::Models::WebhookEvent::QueueItemAction::Data::Object::Item::Content::Object)
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 4202
|