Class: ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: Content, MetaType Classes: ClientAction, Label

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand:, method_:) ⇒ Object

Parameters:

  • brand (String)
  • method_ (String)


# File 'lib/moderation_api/models/webhook_event.rb', line 5990

Instance Attribute Details

#author_idString?

External author ID (the customer’s identifier, not Moderation API’s internal id)

Returns:

  • (String, nil)


5912
# File 'lib/moderation_api/models/webhook_event.rb', line 5912

required :author_id, String, nil?: true

#channel_keyString?

The channel the content was submitted to, identified by your customer-defined channel key.

Returns:

  • (String, nil)


5919
# File 'lib/moderation_api/models/webhook_event.rb', line 5919

required :channel_key, String, nil?: true

#client_actionModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::ClientAction?

A recommendation from your own client-side flagging.



5925
5926
5927
# File 'lib/moderation_api/models/webhook_event.rb', line 5925

required :client_action,
-> { ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::ClientAction },
nil?: true

#conversation_idString?

Conversation grouping ID, if any

Returns:

  • (String, nil)


5940
# File 'lib/moderation_api/models/webhook_event.rb', line 5940

required :conversation_id, String, nil?: true

#flaggedBoolean?

Whether the content was flagged by moderation

Returns:

  • (Boolean, nil)


5946
# File 'lib/moderation_api/models/webhook_event.rb', line 5946

required :flagged, ModerationAPI::Internal::Type::Boolean, nil?: true

#idString

Content ID from your system

Returns:

  • (String)


5906
# File 'lib/moderation_api/models/webhook_event.rb', line 5906

required :id, String

#labelsArray<ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Label>?

Moderation labels applied to the content



5952
5953
5954
5955
5956
# File 'lib/moderation_api/models/webhook_event.rb', line 5952

required :labels,
-> {
  ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::Label]
},
nil?: true

#languageString?

Detected ISO language code, if available

Returns:

  • (String, nil)


5962
# File 'lib/moderation_api/models/webhook_event.rb', line 5962

required :language, String, nil?: true

#meta_typeSymbol, ...

High-level content type (e.g. message, post, comment). Defaults to the channel’s configured content type but can be overridden per request via the moderation API ‘type` field.



5970
5971
5972
5973
5974
# File 'lib/moderation_api/models/webhook_event.rb', line 5970

required :meta_type,
enum: -> {
  ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::MetaType
},
nil?: true

#metadataHash{Symbol=>Object}?

Arbitrary key/value metadata. Top-level keys are strings.

Returns:



5980
5981
5982
# File 'lib/moderation_api/models/webhook_event.rb', line 5980

required :metadata,
ModerationAPI::Internal::Type::HashOf[ModerationAPI::Internal::Type::Unknown],
nil?: true

#timestampTime

ISO 8601 timestamp of when the content was submitted

Returns:

  • (Time)


5988
# File 'lib/moderation_api/models/webhook_event.rb', line 5988

required :timestamp, Time