Class: ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item
- Defined in:
- lib/moderation_api/models/webhook_event.rb
Overview
Defined Under Namespace
Modules: Content, MetaType Classes: Label
Instance Attribute Summary collapse
-
#author_id ⇒ String?
External author ID (the customer’s identifier, not Moderation API’s internal id).
-
#channel_key ⇒ String?
The channel the content was submitted to, identified by your customer-defined channel key.
-
#content ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Text, ...
The original content payload.
-
#conversation_id ⇒ String?
Conversation grouping ID, if any.
-
#flagged ⇒ Boolean?
Whether the content was flagged by moderation.
-
#id ⇒ String
Content ID from your system.
-
#labels ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Label>?
Moderation labels applied to the content.
-
#language ⇒ String?
Detected ISO language code, if available.
-
#meta_type ⇒ Symbol, ...
High-level content type (e.g. message, post, comment).
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata.
-
#timestamp ⇒ Time
ISO 8601 timestamp of when the content was submitted.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(brand:, method_:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand:, method_:) ⇒ Object
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 5729
|
Instance Attribute Details
#author_id ⇒ String?
External author ID (the customer’s identifier, not Moderation API’s internal id)
5659 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5659 required :author_id, String, nil?: true |
#channel_key ⇒ String?
The channel the content was submitted to, identified by your customer-defined channel key.
5666 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5666 required :channel_key, String, nil?: true |
#content ⇒ ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Text, ...
The original content payload
5672 5673 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5672 required :content, union: -> { ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content } |
#conversation_id ⇒ String?
Conversation grouping ID, if any
5679 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5679 required :conversation_id, String, nil?: true |
#flagged ⇒ Boolean?
Whether the content was flagged by moderation
5685 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5685 required :flagged, ModerationAPI::Internal::Type::Boolean, nil?: true |
#id ⇒ String
Content ID from your system
5653 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5653 required :id, String |
#labels ⇒ Array<ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Label>?
Moderation labels applied to the content
5691 5692 5693 5694 5695 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5691 required :labels, -> { ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::Label] }, nil?: true |
#language ⇒ String?
Detected ISO language code, if available
5701 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5701 required :language, String, nil?: true |
#meta_type ⇒ Symbol, ...
High-level content type (e.g. message, post, comment). Defaults to the channel’s configured content type but can be overridden per request via the moderation API ‘type` field.
5709 5710 5711 5712 5713 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5709 required :meta_type, enum: -> { ModerationAPI::WebhookEvent::QueueItemAllowed::Data::Object::Item::MetaType }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata. Top-level keys are strings.
5719 5720 5721 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5719 required :metadata, ModerationAPI::Internal::Type::HashOf[ModerationAPI::Internal::Type::Unknown], nil?: true |
#timestamp ⇒ Time
ISO 8601 timestamp of when the content was submitted
5727 |
# File 'lib/moderation_api/models/webhook_event.rb', line 5727 required :timestamp, Time |
Class Method Details
.variants ⇒ Array(ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Text, ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Image, ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Video, ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Audio, ModerationAPI::Models::WebhookEvent::QueueItemAllowed::Data::Object::Item::Content::Object)
|
|
# File 'lib/moderation_api/models/webhook_event.rb', line 6001
|