Class: ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moderation_api/models/webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: Content, MetaType Classes: Label

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand:, method_:) ⇒ Object

Parameters:

  • brand (String)
  • method_ (String)


# File 'lib/moderation_api/models/webhook_event.rb', line 4746

Instance Attribute Details

#author_idString?

External author ID (the customer’s identifier, not Moderation API’s internal id)

Returns:

  • (String, nil)


4676
# File 'lib/moderation_api/models/webhook_event.rb', line 4676

required :author_id, String, nil?: true

#channel_keyString?

The channel the content was submitted to, identified by your customer-defined channel key.

Returns:

  • (String, nil)


4683
# File 'lib/moderation_api/models/webhook_event.rb', line 4683

required :channel_key, String, nil?: true

#conversation_idString?

Conversation grouping ID, if any

Returns:

  • (String, nil)


4696
# File 'lib/moderation_api/models/webhook_event.rb', line 4696

required :conversation_id, String, nil?: true

#flaggedBoolean?

Whether the content was flagged by moderation

Returns:

  • (Boolean, nil)


4702
# File 'lib/moderation_api/models/webhook_event.rb', line 4702

required :flagged, ModerationAPI::Internal::Type::Boolean, nil?: true

#idString

Content ID from your system

Returns:

  • (String)


4670
# File 'lib/moderation_api/models/webhook_event.rb', line 4670

required :id, String

#labelsArray<ModerationAPI::Models::WebhookEvent::QueueItemRejected::Data::Object::Item::Label>?

Moderation labels applied to the content



4708
4709
4710
4711
4712
# File 'lib/moderation_api/models/webhook_event.rb', line 4708

required :labels,
-> {
  ModerationAPI::Internal::Type::ArrayOf[ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Item::Label]
},
nil?: true

#languageString?

Detected ISO language code, if available

Returns:

  • (String, nil)


4718
# File 'lib/moderation_api/models/webhook_event.rb', line 4718

required :language, String, nil?: true

#meta_typeSymbol, ...

High-level content type (e.g. message, post, comment). Defaults to the channel’s configured content type but can be overridden per request via the moderation API ‘type` field.



4726
4727
4728
4729
4730
# File 'lib/moderation_api/models/webhook_event.rb', line 4726

required :meta_type,
enum: -> {
  ModerationAPI::WebhookEvent::QueueItemRejected::Data::Object::Item::MetaType
},
nil?: true

#metadataHash{Symbol=>Object}?

Arbitrary key/value metadata. Top-level keys are strings.

Returns:



4736
4737
4738
# File 'lib/moderation_api/models/webhook_event.rb', line 4736

required :metadata,
ModerationAPI::Internal::Type::HashOf[ModerationAPI::Internal::Type::Unknown],
nil?: true

#timestampTime

ISO 8601 timestamp of when the content was submitted

Returns:

  • (Time)


4744
# File 'lib/moderation_api/models/webhook_event.rb', line 4744

required :timestamp, Time